make_tls13_aad

Function make_tls13_aad 

pub fn make_tls13_aad(
    typ: ContentType,
    version: ProtocolVersion,
    payload_len: usize,
) -> [u8; 5]
Returns a TLS1.3 additional_data encoding.

For decryption, the parameters should be those that were received on the wire. For encryption, the parameters should be those that will be put on the wire.

See RFC 9846 s5.2 for the additional_data definition.