pub struct VerifiedIdentity<'a>(/* private fields */);Expand description
A peer’s identity, which has been verified.
Implementations
Sourceimpl<'a> VerifiedIdentity<'a>
impl<'a> VerifiedIdentity<'a>
Sourcepub fn assertion(identity: Identity<'a>) -> Self
pub fn assertion(identity: Identity<'a>) -> Self
Make a VerifiedIdentity, noting that identity has been verified somehow.
Sourcepub fn into_owned(self) -> VerifiedIdentity<'static>
pub fn into_owned(self) -> VerifiedIdentity<'static>
Convert the value into an owned one.
This is a straight move if the value is already owned.
Methods from Deref<Target = Identity<'a>>
Sourcepub fn as_signer(&self) -> SignerPublicKey<'_>
pub fn as_signer(&self) -> SignerPublicKey<'_>
Get the public key of this identity as a SignerPublicKey.