#[non_exhaustive]pub enum HandshakeKind {
Full,
FullWithHelloRetryRequest,
Resumed,
ResumedWithHelloRetryRequest,
}Expand description
Describes which sort of handshake happened.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Full
A full handshake.
This is the typical TLS connection initiation process when resumption is
not available, and the initial ClientHello was accepted by the server.
FullWithHelloRetryRequest
A full TLS1.3 handshake, with an extra round-trip for a HelloRetryRequest.
The server can respond with a HelloRetryRequest if the initial ClientHello
is unacceptable for several reasons, the most likely being if no supported key
shares were offered by the client.
Resumed
A resumed handshake.
Resumed handshakes involve fewer round trips and less cryptography than full ones, but can only happen when the peers have previously done a full handshake together, and then remember data about it.
ResumedWithHelloRetryRequest
A resumed handshake, with an extra round-trip for a HelloRetryRequest.
The server can respond with a HelloRetryRequest if the initial ClientHello
is unacceptable for several reasons, but this does not prevent the client
from resuming.