AlertDescription

Struct AlertDescription 

pub struct AlertDescription(pub u8);
The AlertDescription TLS protocol enum. Values in this enum are taken from the various RFCs covering TLS, and are listed by IANA.

The list of alerts is available at https://www.iana.org/assignments/tls-parameters/tls-parameters.xhtml#tls-parameters-6.

Protocol enumerations in rustls are represented with a struct, which contains the numeric value used on the wire (in this case, u8). Each known value has a named const item on this type – this can be used in a match arm or to access the numeric value.

If a known value does not exist for a value you need, you can simply create it locally:

pub const MyValue: AlertDescription = AlertDescription(123);

The Debug impl for this type also looks up and pretty-prints known named items. Unknown values are formatted in hexadecimal.

Tuple Fields

0: u8

Implementations

Source

impl AlertDescription

pub const CloseNotify: Self

Notifies the recipient that the sender will not send any more messages on this connection.

https://www.rfc-editor.org/info/rfc9846/#section-6.1-2.2.1

pub const UnexpectedMessage: Self

An inappropriate message was received.

E.g., the wrong handshake message, premature Application Data, etc. This alert should never be observed in communication between proper implementations.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.2.1

pub const BadRecordMac: Self

This alert is returned if a record is received which cannot be deprotected.

Because AEAD algorithms combine decryption and verification, and also to avoid side-channel attacks, this alert is used for all deprotection failures. This alert should never be observed in communication between proper implementations, except when messages were corrupted in the network.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.4.1

pub const DecryptionFailed: Self

Reserved. Used in TLS versions prior to 1.3.

According to TLS 1.2 specification at https://www.rfc-editor.org/info/rfc5246/ “This alert was used in some earlier versions of TLS, and may have permitted certain attacks against the CBC mode. It MUST NOT be sent by compliant implementations.”

pub const RecordOverflow: Self

TLS record larger than the limit was received.

A TLSCiphertext record was received that had a length more than 214 + 256 bytes, or a record decrypted to a TLSPlaintext record with more than 214 bytes (or some other negotiated limit). This alert should never be observed in communication between proper implementations, except when messages were corrupted in the network.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.6.1

pub const DecompressionFailure: Self

Reserved. Used in TLS versions prior to 1.3.

The decompression function received improper input (e.g., data that would expand to excessive length). This message is always fatal and should never be observed in communication between proper implementations.

https://www.rfc-editor.org/info/rfc5246/

pub const HandshakeFailure: Self

The sender was unable to negotiate an acceptable set of security parameters.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.8.1

pub const NoCertificate: Self

Reserved. Used in SSLv3 but not in TLS.

pub const BadCertificate: Self

A certificate was corrupt, contained signatures that did not verify correctly, etc.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.10.1

pub const UnsupportedCertificate: Self

A certificate was of an unsupported type.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.12.1

pub const CertificateRevoked: Self

A certificate was revoked by its signer.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.14.1

pub const CertificateExpired: Self

A certificate has expired or is not currently valid.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.16.1

pub const CertificateUnknown: Self

Unspecified issue arose in processing the certificate, rendering it unacceptable.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.18.1

pub const IllegalParameter: Self

A field in the handshake was incorrect or inconsistent with other fields.

This alert is used for errors which conform to the formal protocol syntax but are otherwise incorrect.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.20.1

pub const UnknownCa: Self

The CA certificate could not be located or could not be matched with a known trust anchor.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.22.1

pub const AccessDenied: Self

A valid certificate or PSK was received, but did not pass access control.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.24.1

pub const DecodeError: Self

A message could not be decoded.

Some field was out of the specified range or the length of the message was incorrect. This alert is used for errors where the message does not conform to the formal protocol syntax. This alert should never be observed in communication between proper implementations, except when messages were corrupted in the network.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.26.1

pub const DecryptError: Self

A handshake (not record layer) cryptographic operation failed.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.28.1

pub const ExportRestriction: Self

Reserved. Used in TLS 1.0 but not TLS 1.1 or later.

pub const ProtocolVersion: Self

Peer has attempted to negotiate a recognized but not supported protocol version.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.30.1

pub const InsufficientSecurity: Self

The server requires parameters more secure than those supported by the client.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.32.1

pub const InternalError: Self

An internal error unrelated to the peer or the correctness of the protocol.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.34.1

pub const InappropriateFallback: Self

Sent by a server in response to an invalid connection retry attempt from a client.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.36.1

pub const UserCanceled: Self

The sender is canceling the handshake for some reason unrelated to a protocol failure.

https://www.rfc-editor.org/info/rfc9846/#section-6.1-2.4.1

pub const NoRenegotiation: Self

Reserved. Used in TLS versions prior to 1.3.

See TLS 1.2 specification at https://www.rfc-editor.org/info/rfc5246/ for the description.

pub const MissingExtension: Self

A handshake message does not contain an extension that is mandatory to send.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.38.1

pub const UnsupportedExtension: Self

Received an extension not offered in ClientHello or CertificateRequest.

https://www.rfc-editor.org/info/rfc9846/#section-6.2-4.38.1

pub const CertificateUnobtainable: Self

The server is unable to obtain certificate sent as an URL by the client.

https://datatracker.ietf.org/doc/html/rfc6066

pub const UnrecognizedName: Self

The server does not recognize SNI sent by the client.

https://datatracker.ietf.org/doc/html/rfc6066

pub const BadCertificateStatusResponse: Self

pub const BadCertificateHashValue: Self

Reserved. Used in TLS versions prior to 1.3.

https://datatracker.ietf.org/doc/html/rfc6066

pub const UnknownPskIdentity: Self

The server does not recognize PSK identity.

https://datatracker.ietf.org/doc/html/rfc4279

pub const CertificateRequired: Self

A client certificate is desired but none was provided by the client.

https://datatracker.ietf.org/doc/html/rfc9846#section-6.2-4.48.1

pub const GeneralError: Self

An error condition in cases when either no more specific error is available or the sender wishes to conceal the specific error code.

https://datatracker.ietf.org/doc/html/rfc9846#section-6.2-4.49

pub const NoApplicationProtocol: Self

A client ALPN extension advertises only protocols that the server does not support.

https://datatracker.ietf.org/doc/html/rfc9846#section-6.2-4.52.1

pub const EncryptedClientHelloRequired: Self

Use of Encrypted Client Hello is required.

https://datatracker.ietf.org/doc/html/rfc9849#section-11.2

pub fn to_array(self) -> [u8; 1]

Encode the value as a big-endian byte array.