ErrorWithAlert

Struct ErrorWithAlert 

pub struct ErrorWithAlert<'a> {
    pub error: Error,
    /* private fields */
}
An Error along with the (possibly encrypted) alert to send to the peer.

This borrows the output buffer passed to the operation that failed; the alert (if one is to be sent) has been appended to that buffer.

Fields

error: Error

The error

Implementations

Source

impl<'a> ErrorWithAlert<'a>

pub fn tls(&self) -> &[u8]

Yields remaining TLS data, if any, to send to the peer.

The returned slice is the contents of the output buffer passed to the failed operation: the alert (if one is to be sent) and any TLS data generated before the error. Send it to the peer before closing the connection.