#[non_exhaustive]pub enum ClientCertVerifierBuilderError {
NoRootAnchors,
InvalidCrl(CertRevocationListError),
}Expand description
One or more root trust anchors must be provided to create a ClientCertVerifierBuilder. If you wish to disable client authentication, then use WebPkiClientVerifier::no_client_auth instead of constructing a builder.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoRootAnchors
No root trust anchors were provided.
InvalidCrl(CertRevocationListError)
A provided CRL could not be parsed.