pub struct FlushSender<Side: SideData> { /* private fields */ }Expand description
Notification that receiving data may have changed the state of the associated SendTraffic
The caller may wish to check whether there is any IO necessary on the send side. If it does not, and ignores this state, any pending new data to send will be included in the next attempt to send data.
Implementations
Sourceimpl<Side: SideData> FlushSender<Side>
impl<Side: SideData> FlushSender<Side>
Sourcepub fn into_next(self) -> ReceiveTrafficState<'static, Side>
pub fn into_next(self) -> ReceiveTrafficState<'static, Side>
Obtain the next receive-side state.