NeedsInput

Struct NeedsInput 

pub struct NeedsInput<Side: SideData> { /* private fields */ }
More data needs to be supplied to make progress.

Provide the data to Self::process().

Implementations

Source

impl<Side: SideData> NeedsInput<Side>

pub fn process( self, input: &mut dyn TlsInputBuffer, tls: &mut Vec<u8>, ) -> Result<Side::Handshake, Error>

Progress the handshake by receiving further data.

The data is obtained via input. Any output produced is appended to tls and should be sent to the peer (including if this function returns an error, because tls may contain an alert.)

An error from this function is otherwise fatal to the connection, as it consumes the NeedsInput object.

On success, this returns a handshake object specifying what to do to progress the connection. If this contains another NeedsInput object then obtaining more input (eg, from a socket or other source) is certainly necessary.