VecInput

Struct VecInput 

pub struct VecInput { /* private fields */ }
A buffer of TLS bytes read from a socket, stored in a Vec<u8>.

Implementations

Source

impl VecInput

pub fn read(&mut self, rd: &mut dyn Read) -> Result<usize>

Read some bytes from rd, and add them to the buffer.

Once the buffer contains 64 kB of data, we will not read any more bytes until some are consumed by reading from the buffer via Connection::process_new_packets().