VerifyPeerIdentity

Struct VerifyPeerIdentity 

pub struct VerifyPeerIdentity<Side: SideData> { /* private fields */ }
The peer’s presented identity must be verified.

The caller has three choices:

The returned object is a further handshake state for this side. Commonly this will contain a NeedsInput which will accept and process further data.

Implementations

Source

impl<Side: SideData> VerifyPeerIdentity<Side>

pub fn with_config(self, tls: &mut Vec<u8>) -> Result<Side::Handshake, Error>

Progress the handshake by calling the pre-configured certificate verification trait.

pub fn continue_with( self, verification_result: Result<VerifiedIdentity<'static>, Error>, tls: &mut Vec<u8>, ) -> Result<Side::Handshake, Error>

Progress the handshake by incorporating the result of an external verification.

Further data to send to the peer may be appended to tls.

If verification_result is an error, this error is returned and the handshake terminates. An alert may be appended to tls for sending to the peer.

pub fn presented_identity(&self) -> Result<Side::PeerIdentity<'_>, Error>

Inspect the identity that the peer has provided.