Items for use in a client.
Structs
- CertificateTransparencyPolicy
dangerous_configurationPolicy for enforcing Certificate Transparency. - Common configuration for (typically) all connections made by a program.
- This represents a single TLS client connection.
- State associated with a client connection.
- An implementer of
ClientSessionStorethat stores everything in memory. - DangerousClientConfig
dangerous_configurationAccessor for dangerous configuration options. - HandshakeSignatureValid
dangerous_configurationZero-sized marker type representing verification of a signature. - The provided input could not be parsed because it is not a syntactically-valid DNS Name.
- Configuration for how/when a client is allowed to resume a previous session.
- ServerCertVerified
dangerous_configurationZero-sized marker type representing verification of a server cert chain. - A config builder state where the caller needs to supply whether and how to provide a client certificate.
- A config builder state where the caller needs to supply a certificate transparency policy or client certificate resolver.
- WebPkiVerifier
dangerous_configurationDefaultServerCertVerifier, see the trait impl for more information. - Stub that implements io::Write and dispatches to
write_early_data.
Enums
- Encodes ways a client can know the expected name of the server.
- What mechanisms to support for resuming a TLS 1.2 session.
Traits
- A trait for the ability to store client session data, so that sessions can be resumed in future connections.
- A trait for the ability to choose a certificate chain and private key for the purposes of client authentication.
- ServerCertVerifier
dangerous_configurationSomething that can verify a server certificate chain, and verify signatures made by certificates.
Functions
- verify_server_cert_signed_by_trust_anchor
dangerous_configurationVerify that the end-entity certificateend_entityis a valid server cert and chains to at least one of the OwnedTrustAnchor in therootsRootCertStore. - verify_server_name
dangerous_configurationVerify that theend_entityhas a name or alternative name matching theserver_namenote: this only verifies the name and should be used in conjuction with more verification like verify_server_cert_signed_by_trust_anchor