pub struct WriteEarlyData<'a> { /* private fields */ }Expand description
Allows writing of early data in resumed TLS 1.3 connections.
“Early data” is also known as “0-RTT data”.
Use Self::write_tls() to encrypt early data into TLS records.
Implementations
Sourceimpl<'a> WriteEarlyData<'a>
impl<'a> WriteEarlyData<'a>
Sourcepub fn write_tls(
&mut self,
plaintext: OutboundPlain<'_>,
tls: &mut Vec<u8>,
) -> usize
pub fn write_tls( &mut self, plaintext: OutboundPlain<'_>, tls: &mut Vec<u8>, ) -> usize
Encrypt early data as TLS records and encode them into tls.
Yields the number of bytes of plaintext that were consumed. This may be less than
the length of plaintext if the server has limited the amount of early data that
may be sent.
Sourcepub fn bytes_left(&self) -> usize
pub fn bytes_left(&self) -> usize
How many bytes you may send. Writes will become short once this reaches zero.
Sourcepub fn exporter(&mut self) -> Result<KeyingMaterialExporter, Error>
pub fn exporter(&mut self) -> Result<KeyingMaterialExporter, Error>
Returns the “early” exporter that can derive key material for use in early data
See RFC 5705 for general details on what exporters are, and RFC 9846 S7.5 for specific details on the “early” exporter.
Beware that the early exporter requires care, as it is subject to the same potential for replay as early data itself. See RFC 9846 appendix F.5.1 for more detail.
This function can be called at most once per connection. This function will error: if called more than once per connection.
If you are looking for the normal exporter, this is available from
Connection::exporter().