Available on crate feature
ring only.Expand description
ring based CryptoProvider.
Modules
- All defined cipher suites supported by ring appear in this module.
- All defined key exchange groups supported by ring appear in this module.
- Using software keys for authentication.
Structs
- A concrete, safe ticket creation mechanism.
Statics
- A list of all the cipher suites supported by the rustls ring provider.
- A list of all the key exchange groups supported by rustls.
- The cipher suite configuration that an application should use by default.
Functions
- A
CryptoProviderbacked by the ring crate.