pub struct ReadEarlyData<'a> { /* private fields */ }Expand description
Access to early data facilities in resumed TLS1.3 connections.
“Early data” is also known as “0-RTT data”.
The early data itself is read via MessageHandler::next_early_data(); this
type provides the matching “early” keying material exporter.
Implementations
Sourceimpl<'a> ReadEarlyData<'a>
impl<'a> ReadEarlyData<'a>
Sourcepub fn exporter(&mut self) -> Result<KeyingMaterialExporter, Error>
pub fn exporter(&mut self) -> Result<KeyingMaterialExporter, Error>
Returns the “early” exporter that can derive key material for use in early data
See RFC 5705 for general details on what exporters are, and RFC 9846 S7.5 for specific details on the “early” exporter.
Beware that the early exporter requires care, as it is subject to the same potential for replay as early data itself. See RFC 9846 appendix F.5.1 for more detail.
This function can be called at most once per connection. This function will error: if called more than once per connection.
If you are looking for the normal exporter, this is available from
Connection::exporter().