pub trait ResolvesServerCert: Send + Sync {
// Required method
fn resolve(
&self,
client_hello: ClientHello<'_>,
) -> Option<Arc<CertifiedKey>>;
}Expand description
How to choose a certificate chain and signing key for use in server authentication.
Required Methods
Sourcefn resolve(&self, client_hello: ClientHello<'_>) -> Option<Arc<CertifiedKey>>
fn resolve(&self, client_hello: ClientHello<'_>) -> Option<Arc<CertifiedKey>>
Choose a certificate chain and matching key given simplified ClientHello information.
Return None to abort the handshake.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".